NAME

Package::Stash::XS - Faster and more correct implementation of the Package::Stash API

VERSION

version 0.31

This is a trial release!

I use a linearly-increasing version numbering scheme. No meaning should be presumed or inferred from the version being less than 1.0.

SYNOPSIS

use Package::Stash;

DESCRIPTION

This is a backend for Package::Stash, which provides the functionality in a way that's less buggy and much faster. It will be used by default if it's installed, and should be preferred in all environments with a compiler.

BUGS

No known bugs (but see the BUGS section in Package::Stash).

SEE ALSO

Package::Stash

GIVING THANKS

If you found this module to be useful, please show your appreciation by adding a +1 in MetaCPAN and a star in GitHub.

SUPPORT

Bugs may be submitted through the RT bug tracker (or bug-Package-Stash-XS@rt.cpan.org).

AUTHORS

  • Stevan Little <stevan.little@iinteractive.com>

  • Jesse Luehrs <doy@tozt.net>

CONTRIBUTORS

  • Karen Etheridge <ether@cpan.org>

  • Florian Ragwitz <rafl@debian.org>

  • Dave Rolsky <autarch@urth.org>

  • Justin Hunter <justin.d.hunter@gmail.com>

  • Tim Bunce <Tim.Bunce@pobox.com>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Jesse Luehrs.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.